#ifndef _ACCOUNT_STATUS_
#define _ACCOUNT_STATUS_
#include <string>
/// @brief ПОлучение справки о параметрах команды
/// @param isRussian  - указывает выводить ли русскую справку
void AccountHelp(bool isRussian);
/// @brief Получение статуса аккаунта
/// @param address  адресс АПИ
/// @param bkaddress  номер кошелька
/// @param isDebug флаг отладки
int AccountStatus(const std::string address, const char *bkaddress, bool isDebug);

/// @brief Получение информации аккаунта
/// @param address  адресс АПИ
/// @param bkaddress  номер кошелька
/// @param isDebug флаг отладки
int AccountInfo(const std::string address, const char* bkaddress, bool isDebug);

/// @brief Получение Рейтинга аккаунта
/// @param address  адресс АПИ
/// @param bkaddress  номер кошелька
/// @param isDebug флаг отладки
int AccountRaiting(const std::string address, const char* bkaddress, bool isDebug);


/// @brief Получение Рейтинга аккаунта
/// @param address  адресс АПИ
/// @param bkaddress  номер кошелька
/// @param isDebug флаг отладки
/// @param fb - тип фидбэка 0- все p - 1(positive) n-2 (negative)
int AccountFeedbacks(const std::string address, const char* bkaddress, bool isDebug, int fb);

#endif